package service;

import dao.DAOFactory;
import dao.LeaveRequestDAO;
import model.LeaveRequest;
import model.Student;
import model.ApprovalStatus;
import java.util.Date;
import java.util.List;

/**
 * 请假申请服务类
 */
public class LeaveRequestService {
    private final LeaveRequestDAO leaveRequestDAO = DAOFactory.getLeaveRequestDAO();
    private final StudentService studentService = new StudentService();

    /**
     * 提交请假申请
     * @param request 请假申请信息
     * @return 是否提交成功
     */
    public boolean submitLeaveRequest(LeaveRequest request) {
        // 检查学生是否存在
        Student student = studentService.getStudentById(request.getStudent().getId());
        if (student == null) {
            return false;
        }

        // 检查请假时间是否合理
        if (!isValidLeaveTime(request.getStartTime(), request.getEndTime())) {
            return false;
        }

        // 设置初始状态为待审批
        request.setStatus(ApprovalStatus.PENDING);
        request.setRequestTime(new Date());

        return leaveRequestDAO.insert(request) > 0;
    }

    /**
     * 审批请假申请
     * @param requestId 请假申请ID
     * @param status 审批状态
     * @param comment 审批意见
     * @return 是否审批成功
     */
    public boolean approveLeaveRequest(int requestId, ApprovalStatus status, String comment) {
        // 检查请假申请是否存在
        LeaveRequest request = leaveRequestDAO.findById(requestId);
        if (request == null) {
            return false;
        }

        // 检查是否可以审批
        if (request.getStatus() != ApprovalStatus.PENDING) {
            return false;
        }

        return leaveRequestDAO.updateStatus(requestId, status, comment) > 0;
    }

    /**
     * 获取学生的请假记录
     * @param studentId 学生ID
     * @return 请假记录列表
     */
    public List<LeaveRequest> getStudentLeaveRequests(int studentId) {
        return leaveRequestDAO.findByStudentId(studentId);
    }

    /**
     * 获取指定状态的请假申请
     * @param status 审批状态
     * @return 请假申请列表
     */
    public List<LeaveRequest> getLeaveRequestsByStatus(ApprovalStatus status) {
        return leaveRequestDAO.findByStatus(status);
    }

    /**
     * 获取所有请假申请
     * @return 请假申请列表
     */
    public List<LeaveRequest> getAllLeaveRequests() {
        return leaveRequestDAO.findAll();
    }

    /**
     * 根据ID获取请假申请
     * @param requestId 请假申请ID
     * @return 请假申请信息
     */
    public LeaveRequest getLeaveRequestById(int requestId) {
        return leaveRequestDAO.findById(requestId);
    }

    /**
     * 检查请假时间是否合理
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @return 是否合理
     */
    private boolean isValidLeaveTime(Date startTime, Date endTime) {
        // 开始时间不能为空
        if (startTime == null || endTime == null) {
            return false;
        }

        // 结束时间必须在开始时间之后
        if (endTime.before(startTime)) {
            return false;
        }

        // 开始时间不能是过去的时间
        Date now = new Date();
        if (startTime.before(now)) {
            return false;
        }

        return true;
    }
}
